@@ -1,10 +1,10 @@
 # flake8: noqa
 __author__ = "Akio Taniguchi"
-__version__ = "0.2.0"
+__version__ = "0.2.1"
 
 
 # submodules
+from . import article
 from . import apps
-from . import detex
 from . import search
 from . import translate
